@@ -46,7 +46,7 @@ Example counting some events:
 
 
 from ._papi import lib, ffi
-from .types import Flips, Flops, IPC, EPC
+from .papi_high_types import Flips, Flops, IPC, EPC
 from .exceptions import papi_error
 
 
@@ -179,7 +179,7 @@ def flips():
     Simplified call to get Mflips/s (floating point instruction rate), real
     and processor time.
 
-    :rtype: pypapi.types.Flips
+    :rtype: pypapi.papi_high_types.Flips
 
     :raises PapiInvalidValueError: The counters were already started by
         something other than :py:func:`flips`.
@@ -195,11 +195,11 @@ def flips():
     rcode = lib.PAPI_flops(rtime, ptime, flpins, mflips)
 
     return rcode, Flips(
-            ffi.unpack(rtime, 1)[0],
-            ffi.unpack(ptime, 1)[0],
-            ffi.unpack(flpins, 1)[0],
-            ffi.unpack(mflips, 1)[0]
-            )
+        ffi.unpack(rtime, 1)[0],
+        ffi.unpack(ptime, 1)[0],
+        ffi.unpack(flpins, 1)[0],
+        ffi.unpack(mflips, 1)[0],
+    )
 
 
 # int PAPI_flops(float *rtime, float *ptime, long long *flpops, float *mflops);
@@ -210,7 +210,7 @@ def flops():
     Simplified call to get Mflops/s (floating point operation rate), real
     and processor time.
 
-    :rtype: pypapi.types.Flops
+    :rtype: pypapi.papi_high_types.Flops
 
     :raises PapiInvalidValueError: The counters were already started by
         something other than :py:func:`flops`.
@@ -226,11 +226,11 @@ def flops():
     rcode = lib.PAPI_flops(rtime, ptime, flpops, mflops)
 
     return rcode, Flops(
-            ffi.unpack(rtime, 1)[0],
-            ffi.unpack(ptime, 1)[0],
-            ffi.unpack(flpops, 1)[0],
-            ffi.unpack(mflops, 1)[0]
-            )
+        ffi.unpack(rtime, 1)[0],
+        ffi.unpack(ptime, 1)[0],
+        ffi.unpack(flpops, 1)[0],
+        ffi.unpack(mflops, 1)[0],
+    )
 
 
 # int PAPI_ipc(float *rtime, float *ptime, long long *ins, float *ipc);
@@ -240,7 +240,7 @@ def ipc():
 
     Gets instructions per cycle, real and processor time.
 
-    :rtype: pypapi.types.IPC
+    :rtype: pypapi.papi_high_types.IPC
 
     :raises PapiInvalidValueError: The counters were already started by
         something other than :py:func:`ipc`.
@@ -256,11 +256,11 @@ def ipc():
     rcode = lib.PAPI_ipc(rtime, ptime, ins, ipc_)
 
     return rcode, IPC(
-            ffi.unpack(rtime, 1)[0],
-            ffi.unpack(ptime, 1)[0],
-            ffi.unpack(ins, 1)[0],
-            ffi.unpack(ipc_, 1)[0]
-            )
+        ffi.unpack(rtime, 1)[0],
+        ffi.unpack(ptime, 1)[0],
+        ffi.unpack(ins, 1)[0],
+        ffi.unpack(ipc_, 1)[0],
+    )
 
 
 # int PAPI_epc(int event, float *rtime, float *ptime, long long *ref,
@@ -275,7 +275,7 @@ def epc(event=0):
     :param int event: The target event (from :doc:`events`, default:
         :py:const:`pypapi.events.PAPI_TOT_INS`).
 
-    :rtype: pypapi.types.EPC
+    :rtype: pypapi.papi_high_types.EPC
     """
     rtime = ffi.new("float*", 0)
     ptime = ffi.new("float*", 0)
@@ -287,10 +287,10 @@ def epc(event=0):
     rcode = lib.PAPI_epc(event, rtime, ptime, ref, core, evt, epc_)
 
     return rcode, EPC(
-            ffi.unpack(rtime, 1)[0],
-            ffi.unpack(ptime, 1)[0],
-            ffi.unpack(ref, 1)[0],
-            ffi.unpack(core, 1)[0],
-            ffi.unpack(evt, 1)[0],
-            ffi.unpack(epc_, 1)[0]
-            )
+        ffi.unpack(rtime, 1)[0],
+        ffi.unpack(ptime, 1)[0],
+        ffi.unpack(ref, 1)[0],
+        ffi.unpack(core, 1)[0],
+        ffi.unpack(evt, 1)[0],
+        ffi.unpack(epc_, 1)[0],
+    )
